@@ -83,11 +83,7 @@ QString solverStatusMessage(int status, bool everWinnable)
 
 int readIntAttribute(const QXmlStreamReader &xml, const QString &key, bool *ok = nullptr)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QStringRef value = xml.attributes().value(key);
-#else
     QStringView value = xml.attributes().value(key);
-#endif
     return QString::fromRawData(value.data(), value.length()).toInt(ok);
 }
 
@@ -179,9 +175,6 @@ int DealerScene::moveCount() const
 void DealerScene::saveLegacyFile(QIODevice *io)
 {
     QXmlStreamWriter xml(io);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    xml.setCodec("UTF-8");
-#endif
     xml.setAutoFormatting(true);
     xml.setAutoFormattingIndent(-1);
     xml.writeStartDocument();
@@ -324,9 +317,6 @@ bool DealerScene::loadLegacyFile(QIODevice *io)
 void DealerScene::saveFile(QIODevice *io)
 {
     QXmlStreamWriter xml(io);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    xml.setCodec("UTF-8");
-#endif
     xml.setAutoFormatting(true);
     xml.setAutoFormattingIndent(-1);
     xml.writeStartDocument();
